import { scaleOrdinal } from 'd3';

const colorScale = scaleOrdinal()
  .domain(['apple', 'lemon','G-Apple'])
  .range(['#c11d1d', '#eae600', '#56ab2f']);

const radiusScale = scaleOrdinal()
  .domain(['apple', 'lemon','G-Apple'])
  .range([40, 10, 40]);

const xPosition = (d, i) => i * 20;

export const fruitBowl = (selection, props) => {
  const { fruits, height } = props;
  const bowl = selection.selectAll('rect')
    .data([null])
    .enter().append('rect')
      .attr('y', 110)
      .attr('x', 110)
      .attr('width', 720)
      .attr('height', 250)
      .attr('rx', 300 / 2);
  
  const circles = selection.selectAll('circle')
    .data(fruits, d => d.id);

  const groups = selection.selectAll('g')
    .data(fruits);
  const groupsEnter = groups.enter().append('g');
  groupsEnter
    .merge(groups)
      .attr('transform', (d, i) =>
        `translate(${i * 100 + 200},${height / 2})`
      );
  groups.exit().remove();
  
  groupsEnter.append('circle')
    .merge(groups.select('circle'))
      .attr('r', d => radiusScale(d.type))
      .attr('fill', d => colorScale(d.type))
  	.transition().duration(1000)
      .attr('cx', xPosition)
      .attr('r', d => radiusScale(d.type));
  groupsEnter.append('text')
    .merge(groups.select('text'))
      .text(d => d.type)
      .attr('y',120)
  	.transition().duration(1000)
      .text(d => d.type)
      .attr('y', d => radiusScale(d.type) + 20)
      .attr('x', d => radiusScale(d.type) - 10); 
}